-- Marker  Go to/Play Marker

-- nav
-- drag to a sprite 

-- Allows author to assign which event will cause the 'go to label' action
-- drag to sprite
-- also functions through lingo by handling message 'initGotoMarker', 
-- for example if this behavior was assigned to sprite 5, use
-- sendsprite 5, #initGotoMarker

property  whichEvent, whichLabel,playmode

on initGotoMarker me
  init me
end

on mouseUp me
  if whichEvent = #mouseup    then init me
end

on prepareFrame me
  if whichEvent = #prepareframe then init me
end

on exitFrame me
  if whichEvent = #exitframe  then init me
end

on init me
  if the playmode of me = #"Go to" then
    case ( whichLabel ) of:
      #Previous: go to marker( -1 )
      #Loop:     go to marker(  0 )
      #Next:     go to marker(  1 )
      otherwise:
        go to whichLabel    
    end case
  else
    case ( whichLabel ) of:
      #Previous: play marker( -1 )
      #Loop:     play marker(  0 )
      #Next:     play marker(  1 )
      otherwise:
        play whichLabel    
    end case
  end if
  
end




---

on getPropertyDescriptionList
  set p_list = [ ¬
    #WhichLabel: [ #comment:   "Destination Marker:", ¬
                    #format:   #marker, ¬
                   #default:  "#Loop" ], ¬
    #WhichEvent: [ #comment:   "Initializing Event:", ¬
                    #format:   #symbol, ¬
                     #range: [ #MouseUp, #PrepareFrame, #ExitFrame, #InitGotoMarker], ¬
                   #default:   #MouseUp ], ¬
      #playMode: [ #comment:   "Play Mode:", ¬
                    #format:   #symbol, ¬
                     #range: [ #"Go to", #"Play and Return" ], ¬
                   #default:   #"Go to" ] ¬
  ]
  return p_list
end

on getBehaviorDescription
  return ¬
"Moves the Playback Head to a designated marker when the specified event occurs.  Drag to a sprite or a frame in the script channel." && RETURN & ¬
"PARAMETERS:" && RETURN & ¬
"• Destination Marker - Choose from a list of all marker names in the current movie or choose Previous, Loop (Current), or Next."  && RETURN & ¬
"• Initializing Event - Specify the event that triggers the behavior." & RETURN & ¬
"• Play Mode - Choose Play and Return to make the Playback Head return to the current location when the Play Done behavior is encountered. Choose Go To to make the Playback Head continue from the specified frame until explicitly sent to a new location." 
end
