-- Message    Send to Sprite


-- Messaging
-- sends an event to a specified sprite on author selected event
-- the the addressee does not handle the event, it goes to the cast member script
-- then the frame script, then the movie script

-- EventToSend must be a symbol 
-- whichEvent inits the action
-- Addressee is the sprite (channel number) the event is going to

-- also functions through lingo by handling message 'initSendSprite', 
-- for example if this behavior was assigned to sprite 5, use
-- sendsprite 5, #initSendSprite

property whichEvent, addressee, eventToSend, params

on initSendSprite me
  init me
end

on mouseUp me
  if whichEvent = #mouseup  then init me
end

on mouseDown me
  if whichEvent = #mousedown  then init me
end

on prepareFrame me
  if whichEvent = #prepareframe then init me
end

on enterFrame me
  if whichEvent = #enterframe  then init me
end

on exitFrame me
  if whichEvent = #exitframe  then init me
end

on init me
   set doit = "sendSprite the Addressee of me, the EventToSend of me," && params
  do doit
end

---

on getPropertyDescriptionList  
  
  set p_list = [ ¬
   #EventToSend: [ #comment:   "Message:", ¬
                    #format:   #symbol, ¬
                   #default:   #generic_event ], ¬
   #Params:      [ #comment:   "Param1, param2, ...", ¬
                    #format:   #string, ¬
                   #default:   "" ], ¬
  #Addressee: [ #comment:   "Target Sprite:", ¬
                    #format:   #integer, ¬
                   #default:    1 ], ¬
    #WhichEvent: [ #comment:   "Initializing Event:", ¬
                    #format:   #symbol, ¬
                     #range: [ #MouseUp, #MouseDown, #PrepareFrame, #EnterFrame, #ExitFrame, #InitSendSprite], ¬
                   #default:   #MouseUp ] ¬
                 ]
  return p_list  
  
end

on getBehaviorDescription
  return ¬
"Sends a message to the designated sprite when the specified event occurs.  Any behaviors attached to the target sprite that are triggered by the message will be executed." & RETURN & ¬
"PARAMETERS:" & RETURN & ¬
"• Message - Enter the message to send to the target sprite."  & RETURN & ¬
"• Params  - Enter parameters to be sent with the message, seperated with commas."  & RETURN & ¬
"• Target Sprite - Enter the number of the sprite channel to which message should be sent."  & RETURN & ¬
"• Initializing Event - Specify the event that triggers the behavior." & RETURN & ¬
"NOTES:" & RETURN & ¬
"If there is no behavior attached to the target sprite that responds to the message being sent, the message is passed to the cast member script, the current frame script, and then movie scripts." 
  
  
end