-- Movie in a Window Message 



-- will 'tell' a movie to 'do' something, optionally a text field can be looked at for additional commands.
-- 
-- also functions through lingo by handling message 'initMIAWMessage', 
-- for example if this behavior was assigned to sprite 5, use
-- sendsprite 5, #initMIAWMessage

property  windowName, commandName, parameters, whichEvent

on initMIAWMessage me
  init me
end

on mouseUp me
  if whichEvent = #mouseup    then init me
end

on mouseDown me
  if whichEvent = #mousedown  then init me
end

on prepareFrame me
  if whichEvent = #prepareframe then init me
end

on enterFrame me
  if whichEvent = #enterframe then init me
end

on exitFrame me
  if whichEvent = #exitframe  then init me
end

on init me
  if ( word 1 of parameters = "field" ) then
    set parameters = the text of field ( word 2 of parameters )
  else if ( word 1 of parameters = "sprite" ) then
    set parameters = field the castNum of sprite ( word 2 of parameters )    
  end if
  set argv = "(" & QUOTE & parameters & QUOTE & ")"
  tell window ( the windowName of me ) to do ( the commandName of me ) && argv
end

---

on getPropertyDescriptionList
  
  set p_list = [ ¬
     #commandName: [ #comment:   "Command:", ¬
                      #format:   #string, ¬
                     #default:    "                                     " ], ¬
      #parameters: [ #comment:   "Parameters:", ¬
                      #format:   #string, ¬
                     #default:    "                                     " ], ¬
      #windowName: [ #comment:   "Target Window:", ¬
                      #format:   #string, ¬
                     #default:    "" ], ¬
      #WhichEvent: [ #comment:   "Initializing Event:", ¬
                      #format:   #symbol, ¬
                       #range: [ #MouseUp, #MouseDown, #PrepareFrame, #EnterFrame, #ExitFrame, #InitMIAWMessage], ¬
                     #default:   #MouseUp ] ¬
                 ]
  return p_list  
end

on getBehaviorDescription
  return ¬
"Sends a command or message to a movie in a window.  Enter arguments in the Parameters text entry box." & RETURN & ¬
"PARAMETERS:" & RETURN & ¬
"• Command - Enter the name of command to send window." & RETURN & ¬
"• Parameters - Enter the arguments required by the command." & RETURN & ¬
"• Target Window - Enter the name of the window to which the message should be delivered." & RETURN & ¬
"• Initializing Event - Specify the event that triggers the behavior."& RETURN & ¬
"NOTES:" & RETURN & ¬
"If the first two words in the Parameters box are 'field' (without quotes) followed by the name of the field cast member (enclosed in double quotes) then the text in the field cast member will be used as the argument for the command begin sent."
end

