-- Image Switch Members

-- Media

-- Adding this behavior to a sprite allows it to change its cast member when
-- it receives an event.
-- The sprite checks the parameter passed with the event and if it matches the
-- assigned name of the sprite or the assigned 'groupname' of the sprite
-- it switches.  This way multiple sprites can be effected by a single message.

-- autohandles MemberAlt, MemberOne being numbers or labels.

-- MemberAlt is a cast member (graphic or pict)
-- MemberOne is also
-- Setting is with 1 ( normal ) or 2 ( toggled ) and is also starting state
-- Name is a symbol which is checked for when the script receives a Switch event
-- GroupName is also a symbol checked for, must be a symbol

-- receives Switch name

property  Name, Setting, Memberalt, MemberOne, GroupName
property MemberAltName 

on SetState me, state, addressee
  if voidP(Addressee) then
    do_SetState me, state
  else    
    case Addressee of
      #all: do_SetState me, state
      (the Name of me): do_SetState me, state
      (the GroupName of me): do_SetState me, state
    end case
  end if
end

on SwitchStates me, Addressee 
  if voidP( Addressee ) then
    do_SwitchStates me
  else    
    case Addressee of
      #all: do_SwitchStates me
      (the Name of me): do_SwitchStates me
      (the GroupName of me): do_SwitchStates me
    end case
  end if 
end

---
on do_SetState me, state 
  set the Setting of me = state
  if state = 1 then
    set the member of sprite the spritenum of me to the MemberOne of me
  else
    set the member of sprite the spritenum of me to the MemberAlt of me
  end if
end

on do_SwitchStates me
  if ( the Setting of me = 1 ) then
    set the Setting of me = 2
    set the member of sprite the spritenum of me to the MemberAlt of me
  else if ( the Setting of me = 2 ) then
    set the Setting of me = 1
    set the member of sprite the spritenum of me to the MemberOne of me
  end if
  return the Setting of me
end

---

on BeginSprite me
  
  set the MemberOne of me = the member of sprite ( the spriteNum of me ) 
  set the MemberAlt of me = member ( the MemberAltName of me ) 
  
  if setting = TRUE then -- initially alternate
    do_SetState me, 2 
  else  -- initally memberOne.
    do_SetState me, 1 
  end if 
end

on getPropertyDescriptionList
  if the currentspritenum = 0 then 
    set memdefault = 0 
  else
    set memref = the member of sprite the currentspritenum
    set castlibnum = the castlibnum of memref
    set memdefault = member (the membernum of member memref + 1) of castlib castlibnum
  end if
  
  set p_list = [ ¬
          #Name: [ #comment:   "Item Name:", ¬
                    #format:   #symbol, ¬
                   #default:   #twostate1 ], ¬
     #MemberAltName: [ #comment:   "Alternate Image Name:", ¬
                   #format:   #graphic, ¬
                   #default:    memdefault], ¬
       #Setting: [ #comment:   "Initially Toggled:", ¬
                    #format:   #boolean, ¬
                   #default:    FALSE ], ¬
     #GroupName: [ #comment:   "Group Name:", ¬
                    #format:   #symbol, ¬
                   #default:   #group1 ] ¬
                 ]
  
  return p_list  
  
end

on getBehaviorDescription
  return ¬
"Switches cast members when the SwitchStates message is received. Switches to a particular state when the SetState message is received. Enter a Group Name to include the current sprite in a group of sprites that respond to the same message. " & RETURN & ¬
"PARAMETERS:" & RETURN & ¬
"• Item Name - (optional) Enter an item name to identify the current sprite so that it can receive a specific message. Do not use spaces. Use the name as an argument for the Message Sprite or Message All Sprites behaviors."  & RETURN & ¬
"• Alternate Image - number of castmember whose image will replace normal image.  Must be stored in same cast library as Normal castmember."  & RETURN & ¬
"• Initially Toggled - Turn this option on if sprite's current cast member represents the alternate rather than the normal state of the sprite."  & RETURN & ¬
"• Group Name - (optional) Enter a Group Name to include the current sprite in a group of sprites that respond to the same message. Do not use spaces. Use the name as an argument for the Message Sprite or Message All Sprites behaviors."  & RETURN & ¬
"MESSAGES:" & RETURN & ¬
"• SwitchStates [ID] - Switches the sprite's cast member. ID is the Item Name or Group Name of the sprite. Returns the current state of the sprite, 0 (normal) or 1 (alternate)."& RETURN & ¬
"• SetState {0 or 1}, [ID] - Sets the sprite to state 0 (normal) or 1 (alternate). ID is the Item Name or Group Name of the sprite. If the ID is omitted any sprite receiving the message will SetState."
  
end



on getAssocMembers --added, fmk
  set myPropList = [MemberAltName ]
  
  return myPropList
end getAssocMembers