-- Pointer Animate


-- n state cycling, bounce list used to animate the cursor
-- relies on cast members being contiguous
-- handles StartCursor and EndCursor

property RCustomImage, RPointerStyle, RCustomMask
property speed
property enabled  -- if False cursor does not animate
property membermin, membermax
property cycling   -- if not cycling, bouncing
property goingup   -- TRUE if going up through the list,
--                    FALSE if going down
property currentcursor
property numstates

property tickcount -- used to keep the clock
property useCustom, startBegin, stopEnd

on StartAnimation me
  set the enabled of me = TRUE
end

on StopAnimation me
  set the enabled of me = FALSE
  set currentPointer = translate_cursor( me, RpointerStyle, RcustomImage, RcustomMask, useCustom  )
  cursor( currentPointer )
  
end


on translate_cursor me, setting, image, mask, custom
  if custom then
    set val = [ member image, member mask ]
    return val
  end if
  return setting
end


on setCursor me, statenum
  if the enabled of me then
    if statenum > the numstates of me then set statenum = the numstates of me
    cursor [ member (statenum + (the membernum of member (the membermin of me)) - 1) ]
  end if
end

on setGoingup me, value
  set the goingup of me to value
end

on setCycle me, value
  set the cycling of me to value
end

on prepareframe me
  if the ticks > the tickcount of me + the speed of me then
    NextState me
    set the tickcount of me = the ticks
  end if
end

on NextState me
  if the enabled of me then
    if the cycling of me then
      if the goingup of me then
        set curr = the currentcursor of me  + 1
        if curr > the numstates of me then 
          set curr = 1
        end if
      else -- going down
        set curr = the currentcursor of me  - 1
        if curr < 1 then set curr = the numstates of me
      end if
      
    else -- bouncing
      if the goingup of me then 
        set curr = the currentcursor of me  + 1
        if curr > the numstates of me then
          set curr = curr - 2
          set the goingup of me = FALSE
        end if
      else   --goingUp == FALSE
        set curr = the currentcursor of me  - 1
        if curr < 1 then
          set curr = 2
          set the goingup of me = TRUE
        end if
      end if
    end if
    
    set the currentcursor of me = curr
    setcursor me, curr
  end if
end

---

on BeginSprite me
  set the enabled of me = FALSE
  set the numstates of me = (the membermax of me) - (the membermin of me) + 1
  set the tickcount of me = the ticks
  if Cycling = #Repeat then set Cycling = TRUE
  if Cycling = #Reverse then set Cycling = FALSE
  if goingup = true then 
    set goingup= false 
  else set goingup = true 
  
  if startBegin then startAnimation me
  
end

on Endsprite me
  if stopEnd then
    set currentPointer = translate_cursor( me, RpointerStyle, RcustomImage, RcustomMask, useCustom  )
    cursor( currentPointer )
  end if
  
end

on getPropertyDescriptionList
  
  set p_list = [ ¬
  #startBegin:[ #comment:      "Start Animation on beginSprite:", ¬
                    #format:   #boolean, ¬
                   #default:    FALSE ], ¬
       #stopEnd: [ #comment:   "Restore Cursor on endSprite:", ¬
                    #format:   #boolean, ¬
                   #default:    TRUE ], ¬
  #MemberMin: [ #comment:      "First Image:", ¬
                    #format:   #bitmap, ¬
                   #default:    member 1 ], ¬
     #MemberMax: [ #comment:   "Last Image:", ¬
                    #format:   #bitmap, ¬
                   #default:    member 1 ], ¬
         #Speed: [ #comment:   "Step Rate:", ¬
                    #format:   #integer, ¬
                   #default:    10 ], ¬
       #Cycling: [ #comment:   "Cycle Mode:", ¬
                    #format:   #symbol, ¬
                     #range: [ #Repeat, #Reverse ], ¬
                   #default:   #Repeat ], ¬
       #Goingup: [ #comment:   "Reverse Order:", ¬
                    #format:   #boolean, ¬
                   #default:    FALSE ], ¬
   #RpointerStyle: [ #comment: "Restored Pointer Image:", ¬
                    #format:   #cursor, #default:1], ¬
       #useCustom: [ #comment: "Restore Custom Pointer:", ¬
                    #format:   #boolean, ¬
                   #default:    FALSE ], ¬
  #RcustomImage: [ #comment:   "Restored Custom Image:", ¬
                    #format:   #bitmap, ¬
                   #default:    member 1 ], ¬
    #RcustomMask: [ #comment:   "Restored Custom Mask:", ¬
                    #format:   #bitmap, ¬
                   #default:    member 1 ]  ]
  return p_list    
  return description
end

on getBehaviorDescription
  return ¬
"Animates the pointer image using a series of adjacent 1-bit bitmapped cast members.  Drag to any sprite or place in the sript channel." & RETURN & ¬
"PARAMETERS:" & RETURN & ¬
"• Start on BeginSprite - Turn this option on to start animation when the sprite begins."  & RETURN & ¬
"• Restore - Turn this option to restore the pointer when the sprite ends."  & RETURN & ¬
"• First Image - Choose the first cast member in the animation sequence."  & RETURN & ¬
"• Last Image  - Choose the last cast member in the animation sequence."  & RETURN & ¬
"• Initial Image - Choose the cast member that should be visible when the animation begins."  & RETURN & ¬
"• Step Rate - Enter the rate, in ticks ( 1/60 second units ) at which the pointer image should change during animation."  & RETURN & ¬
"• Cycle Mode - Choose Repeat to show the same sequence every time.  Choose Reverse to alternate between playing the sequence forward and backward." & RETURN & ¬
"• Reverse Order - Turn this option on to proceed from the last to first image by default."  & RETURN & ¬
"• Restored Pointer - Choose one of Director's included pointers to be displayed when the sprite ends."  & RETURN & ¬
"• Use Custom Pointer - Turn this option on to use a cast member instead of an included pointer as the restored pointer image."  & RETURN & ¬
"• Restored Custom Image  - ( optional ) Choose which cast member to use as the restored pointer image."  & RETURN & ¬
"• Restored Custom Mask - ( optional ) Choose a cast member to use as a mask image when sprite ends.  "& RETURN & ¬
"MESSAGES:" & RETURN & ¬
"• StartAnimation - Begin the pointer animation."  & RETURN & ¬
"• StopAnimation - End the pointer animation."
end


